﻿using Microsoft.Phone.Controls;
using System.Collections.Generic;
using System.ComponentModel;
using System.Globalization;
using System.Runtime.CompilerServices;

namespace PhoneApp1
{
    public partial class MainPage : PhoneApplicationPage
    {
        private readonly ViewModel _vm;
        // Constructor
        public MainPage()
        {
            InitializeComponent();

            _vm = new ViewModel(this);
            this.ContentPanel.DataContext = _vm;
        }

        private void LongListSelector_SelectionChanged(object sender, System.Windows.Controls.SelectionChangedEventArgs e)
        {
            if (e.AddedItems.Count > 0)
            {
                var culture = e.AddedItems[0] as string;
                if (culture != null)
                {
                    _vm.CurrentLanguage = culture;
                }
            }
        }
    }

    public class ViewModel : INotifyPropertyChanged
    {
        private readonly MainPage _page;
        public ViewModel(MainPage page)
        {
            _page = page;
        }

        public IEnumerable<string> AvailableLanguages
        {
            get
            {
                return new[] { "en-us", "fr-fr", "es", "qps-ploc" };
            }
        }

        private string _currentLanguage;
        public object CurrentLanguage
        {
            get
            {
                return _currentLanguage;
            }
            set
            {
                if (_currentLanguage != (string)value)
                {
                    _currentLanguage = (string)value;
                    OnPropertyChanged();

                    ChangeUICulture(_currentLanguage);
                }
            }
        }

        private void ChangeUICulture(string currentLanguage)
        {
            _page.Dispatcher.BeginInvoke(() =>
            {
                var culture = new CultureInfo(currentLanguage);
                System.Threading.Thread.CurrentThread.CurrentCulture =
                    System.Threading.Thread.CurrentThread.CurrentUICulture = culture;

                this.OnPropertyChanged("TextToDisplay");
            });
        }

        public string TextToDisplay
        {
            get
            {
                return Resources.AppResources.testString;
            }
        }

        public event PropertyChangedEventHandler PropertyChanged;
        private void OnPropertyChanged([CallerMemberName]string propertyName = "")
        {
            if (this.PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }
    }
}